<?php

namespace Drupal\domain_role\Plugin\views\filter;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\domain\DomainNegotiatorInterface;
use Drupal\user\Plugin\views\filter\Roles;
use Drupal\user\RoleStorageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;


/**
 * Filters for users with roles in this domain.
 *
 * @ingroup views_filter_handlers
 *
 * @ViewsFilter("domain_roles")
 */
class DomainRoles extends Roles {

  /**
   * @var DomainNegotiatorInterface
   */
  protected $domainNegotiator;

  /**
   * @var ConfigFactoryInterface
   */
  protected $configFactory;

  public function __construct(array $configuration, string $plugin_id,
    $plugin_definition,
    RoleStorageInterface $role_storage,
    DomainNegotiatorInterface $domainNegotiator,
    ConfigFactoryInterface $configFactory) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $role_storage);
    $this->domainNegotiator = $domainNegotiator;
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')->getStorage('user_role'),
      $container->get('domain.negotiator'),
      $container->get('config.factory')
    );
  }

  /**
   * Override keys to domain-specific roles.
   */
  public function getValueOptions() {
    $options = parent::getValueOptions();
    $currentDomain = $this->domainNegotiator->getActiveId();
    $domain_roles = $this->configFactory->get('domain_role.roles')->get('domain_roles');
    $domain_roles = array_filter($domain_roles);
    $newoptions = [];
    foreach ($options as $key => $option) {
      if (in_array($key, $domain_roles)) {
        $newoptions[$currentDomain . '-' . $key] = $option;
      } else {
        $newoptions[$key] = $option;
      }
    }
    $this->valueOptions = $newoptions;
    return $this->valueOptions;
  }

}
